# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: routing.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from . import CasperMessage_pb2 as CasperMessage__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='routing.proto',
  package='routing',
  syntax='proto3',
  serialized_options=_b('\342?%\n!coop.rchain.comm.protocol.routing\020\001'),
  serialized_pb=_b('\n\rrouting.proto\x12\x07routing\x1a\x15scalapb/scalapb.proto\x1a\x13\x43\x61sperMessage.proto\"D\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x0c\n\x04host\x18\x02 \x01(\x0c\x12\x10\n\x08tcp_port\x18\x03 \x01(\r\x12\x10\n\x08udp_port\x18\x04 \x01(\r\":\n\x06Header\x12\x1d\n\x06sender\x18\x01 \x01(\x0b\x32\r.routing.Node\x12\x11\n\tnetworkId\x18\x02 \x01(\t\"\x0b\n\tHeartbeat\"\x13\n\x11HeartbeatResponse\"\"\n\x11ProtocolHandshake\x12\r\n\x05nonce\x18\x01 \x01(\x0c\"*\n\x19ProtocolHandshakeResponse\x12\r\n\x05nonce\x18\x01 \x01(\x0c\")\n\x06Packet\x12\x0e\n\x06typeId\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"\x0c\n\nDisconnect\"\xb2\x02\n\x08Protocol\x12\x1f\n\x06header\x18\x01 \x01(\x0b\x32\x0f.routing.Header\x12\'\n\theartbeat\x18\x02 \x01(\x0b\x32\x12.routing.HeartbeatH\x00\x12\x38\n\x12protocol_handshake\x18\x03 \x01(\x0b\x32\x1a.routing.ProtocolHandshakeH\x00\x12I\n\x1bprotocol_handshake_response\x18\x04 \x01(\x0b\x32\".routing.ProtocolHandshakeResponseH\x00\x12!\n\x06packet\x18\x05 \x01(\x0b\x32\x0f.routing.PacketH\x00\x12)\n\ndisconnect\x18\x06 \x01(\x0b\x32\x13.routing.DisconnectH\x00\x42\t\n\x07message\"0\n\tTLRequest\x12#\n\x08protocol\x18\x01 \x01(\x0b\x32\x11.routing.Protocol\"$\n\x13InternalServerError\x12\r\n\x05\x65rror\x18\x01 \x01(\x0c\"&\n\x03\x41\x63k\x12\x1f\n\x06header\x18\x01 \x01(\x0b\x32\x0f.routing.Header\"q\n\nTLResponse\x12\x1b\n\x03\x61\x63k\x18\x01 \x01(\x0b\x32\x0c.routing.AckH\x00\x12;\n\x13internalServerError\x18\x02 \x01(\x0b\x32\x1c.routing.InternalServerErrorH\x00\x42\t\n\x07payload\"z\n\x0b\x43hunkHeader\x12\x1d\n\x06sender\x18\x01 \x01(\x0b\x32\r.routing.Node\x12\x0e\n\x06typeId\x18\x02 \x01(\t\x12\x12\n\ncompressed\x18\x03 \x01(\x08\x12\x15\n\rcontentLength\x18\x04 \x01(\x05\x12\x11\n\tnetworkId\x18\x05 \x01(\t\" \n\tChunkData\x12\x13\n\x0b\x63ontentData\x18\x01 \x01(\x0c\"^\n\x05\x43hunk\x12&\n\x06header\x18\x01 \x01(\x0b\x32\x14.routing.ChunkHeaderH\x00\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x12.routing.ChunkDataH\x00\x42\t\n\x07\x63ontent2v\n\x0eTransportLayer\x12\x31\n\x04Send\x12\x12.routing.TLRequest\x1a\x13.routing.TLResponse\"\x00\x12\x31\n\x06Stream\x12\x0e.routing.Chunk\x1a\x13.routing.TLResponse\"\x00(\x01\x42(\xe2?%\n!coop.rchain.comm.protocol.routing\x10\x01\x62\x06proto3')
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,CasperMessage__pb2.DESCRIPTOR,])




_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='routing.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='routing.Node.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host', full_name='routing.Node.host', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcp_port', full_name='routing.Node.tcp_port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='udp_port', full_name='routing.Node.udp_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=138,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='routing.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='routing.Header.sender', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkId', full_name='routing.Header.networkId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=198,
)


_HEARTBEAT = _descriptor.Descriptor(
  name='Heartbeat',
  full_name='routing.Heartbeat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=211,
)


_HEARTBEATRESPONSE = _descriptor.Descriptor(
  name='HeartbeatResponse',
  full_name='routing.HeartbeatResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=232,
)


_PROTOCOLHANDSHAKE = _descriptor.Descriptor(
  name='ProtocolHandshake',
  full_name='routing.ProtocolHandshake',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='routing.ProtocolHandshake.nonce', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=268,
)


_PROTOCOLHANDSHAKERESPONSE = _descriptor.Descriptor(
  name='ProtocolHandshakeResponse',
  full_name='routing.ProtocolHandshakeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='routing.ProtocolHandshakeResponse.nonce', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=312,
)


_PACKET = _descriptor.Descriptor(
  name='Packet',
  full_name='routing.Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='typeId', full_name='routing.Packet.typeId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='routing.Packet.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=355,
)


_DISCONNECT = _descriptor.Descriptor(
  name='Disconnect',
  full_name='routing.Disconnect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=369,
)


_PROTOCOL = _descriptor.Descriptor(
  name='Protocol',
  full_name='routing.Protocol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='routing.Protocol.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heartbeat', full_name='routing.Protocol.heartbeat', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol_handshake', full_name='routing.Protocol.protocol_handshake', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol_handshake_response', full_name='routing.Protocol.protocol_handshake_response', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packet', full_name='routing.Protocol.packet', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disconnect', full_name='routing.Protocol.disconnect', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='routing.Protocol.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=372,
  serialized_end=678,
)


_TLREQUEST = _descriptor.Descriptor(
  name='TLRequest',
  full_name='routing.TLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='routing.TLRequest.protocol', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=680,
  serialized_end=728,
)


_INTERNALSERVERERROR = _descriptor.Descriptor(
  name='InternalServerError',
  full_name='routing.InternalServerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='routing.InternalServerError.error', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=730,
  serialized_end=766,
)


_ACK = _descriptor.Descriptor(
  name='Ack',
  full_name='routing.Ack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='routing.Ack.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=768,
  serialized_end=806,
)


_TLRESPONSE = _descriptor.Descriptor(
  name='TLResponse',
  full_name='routing.TLResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ack', full_name='routing.TLResponse.ack', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internalServerError', full_name='routing.TLResponse.internalServerError', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='routing.TLResponse.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=808,
  serialized_end=921,
)


_CHUNKHEADER = _descriptor.Descriptor(
  name='ChunkHeader',
  full_name='routing.ChunkHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='routing.ChunkHeader.sender', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='typeId', full_name='routing.ChunkHeader.typeId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed', full_name='routing.ChunkHeader.compressed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contentLength', full_name='routing.ChunkHeader.contentLength', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networkId', full_name='routing.ChunkHeader.networkId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=923,
  serialized_end=1045,
)


_CHUNKDATA = _descriptor.Descriptor(
  name='ChunkData',
  full_name='routing.ChunkData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contentData', full_name='routing.ChunkData.contentData', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1047,
  serialized_end=1079,
)


_CHUNK = _descriptor.Descriptor(
  name='Chunk',
  full_name='routing.Chunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='routing.Chunk.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='routing.Chunk.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='routing.Chunk.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1081,
  serialized_end=1175,
)

_HEADER.fields_by_name['sender'].message_type = _NODE
_PROTOCOL.fields_by_name['header'].message_type = _HEADER
_PROTOCOL.fields_by_name['heartbeat'].message_type = _HEARTBEAT
_PROTOCOL.fields_by_name['protocol_handshake'].message_type = _PROTOCOLHANDSHAKE
_PROTOCOL.fields_by_name['protocol_handshake_response'].message_type = _PROTOCOLHANDSHAKERESPONSE
_PROTOCOL.fields_by_name['packet'].message_type = _PACKET
_PROTOCOL.fields_by_name['disconnect'].message_type = _DISCONNECT
_PROTOCOL.oneofs_by_name['message'].fields.append(
  _PROTOCOL.fields_by_name['heartbeat'])
_PROTOCOL.fields_by_name['heartbeat'].containing_oneof = _PROTOCOL.oneofs_by_name['message']
_PROTOCOL.oneofs_by_name['message'].fields.append(
  _PROTOCOL.fields_by_name['protocol_handshake'])
_PROTOCOL.fields_by_name['protocol_handshake'].containing_oneof = _PROTOCOL.oneofs_by_name['message']
_PROTOCOL.oneofs_by_name['message'].fields.append(
  _PROTOCOL.fields_by_name['protocol_handshake_response'])
_PROTOCOL.fields_by_name['protocol_handshake_response'].containing_oneof = _PROTOCOL.oneofs_by_name['message']
_PROTOCOL.oneofs_by_name['message'].fields.append(
  _PROTOCOL.fields_by_name['packet'])
_PROTOCOL.fields_by_name['packet'].containing_oneof = _PROTOCOL.oneofs_by_name['message']
_PROTOCOL.oneofs_by_name['message'].fields.append(
  _PROTOCOL.fields_by_name['disconnect'])
_PROTOCOL.fields_by_name['disconnect'].containing_oneof = _PROTOCOL.oneofs_by_name['message']
_TLREQUEST.fields_by_name['protocol'].message_type = _PROTOCOL
_ACK.fields_by_name['header'].message_type = _HEADER
_TLRESPONSE.fields_by_name['ack'].message_type = _ACK
_TLRESPONSE.fields_by_name['internalServerError'].message_type = _INTERNALSERVERERROR
_TLRESPONSE.oneofs_by_name['payload'].fields.append(
  _TLRESPONSE.fields_by_name['ack'])
_TLRESPONSE.fields_by_name['ack'].containing_oneof = _TLRESPONSE.oneofs_by_name['payload']
_TLRESPONSE.oneofs_by_name['payload'].fields.append(
  _TLRESPONSE.fields_by_name['internalServerError'])
_TLRESPONSE.fields_by_name['internalServerError'].containing_oneof = _TLRESPONSE.oneofs_by_name['payload']
_CHUNKHEADER.fields_by_name['sender'].message_type = _NODE
_CHUNK.fields_by_name['header'].message_type = _CHUNKHEADER
_CHUNK.fields_by_name['data'].message_type = _CHUNKDATA
_CHUNK.oneofs_by_name['content'].fields.append(
  _CHUNK.fields_by_name['header'])
_CHUNK.fields_by_name['header'].containing_oneof = _CHUNK.oneofs_by_name['content']
_CHUNK.oneofs_by_name['content'].fields.append(
  _CHUNK.fields_by_name['data'])
_CHUNK.fields_by_name['data'].containing_oneof = _CHUNK.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Heartbeat'] = _HEARTBEAT
DESCRIPTOR.message_types_by_name['HeartbeatResponse'] = _HEARTBEATRESPONSE
DESCRIPTOR.message_types_by_name['ProtocolHandshake'] = _PROTOCOLHANDSHAKE
DESCRIPTOR.message_types_by_name['ProtocolHandshakeResponse'] = _PROTOCOLHANDSHAKERESPONSE
DESCRIPTOR.message_types_by_name['Packet'] = _PACKET
DESCRIPTOR.message_types_by_name['Disconnect'] = _DISCONNECT
DESCRIPTOR.message_types_by_name['Protocol'] = _PROTOCOL
DESCRIPTOR.message_types_by_name['TLRequest'] = _TLREQUEST
DESCRIPTOR.message_types_by_name['InternalServerError'] = _INTERNALSERVERERROR
DESCRIPTOR.message_types_by_name['Ack'] = _ACK
DESCRIPTOR.message_types_by_name['TLResponse'] = _TLRESPONSE
DESCRIPTOR.message_types_by_name['ChunkHeader'] = _CHUNKHEADER
DESCRIPTOR.message_types_by_name['ChunkData'] = _CHUNKDATA
DESCRIPTOR.message_types_by_name['Chunk'] = _CHUNK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.Node)
  })
_sym_db.RegisterMessage(Node)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.Header)
  })
_sym_db.RegisterMessage(Header)

Heartbeat = _reflection.GeneratedProtocolMessageType('Heartbeat', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEAT,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.Heartbeat)
  })
_sym_db.RegisterMessage(Heartbeat)

HeartbeatResponse = _reflection.GeneratedProtocolMessageType('HeartbeatResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATRESPONSE,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.HeartbeatResponse)
  })
_sym_db.RegisterMessage(HeartbeatResponse)

ProtocolHandshake = _reflection.GeneratedProtocolMessageType('ProtocolHandshake', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLHANDSHAKE,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.ProtocolHandshake)
  })
_sym_db.RegisterMessage(ProtocolHandshake)

ProtocolHandshakeResponse = _reflection.GeneratedProtocolMessageType('ProtocolHandshakeResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLHANDSHAKERESPONSE,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.ProtocolHandshakeResponse)
  })
_sym_db.RegisterMessage(ProtocolHandshakeResponse)

Packet = _reflection.GeneratedProtocolMessageType('Packet', (_message.Message,), {
  'DESCRIPTOR' : _PACKET,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.Packet)
  })
_sym_db.RegisterMessage(Packet)

Disconnect = _reflection.GeneratedProtocolMessageType('Disconnect', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECT,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.Disconnect)
  })
_sym_db.RegisterMessage(Disconnect)

Protocol = _reflection.GeneratedProtocolMessageType('Protocol', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOL,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.Protocol)
  })
_sym_db.RegisterMessage(Protocol)

TLRequest = _reflection.GeneratedProtocolMessageType('TLRequest', (_message.Message,), {
  'DESCRIPTOR' : _TLREQUEST,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.TLRequest)
  })
_sym_db.RegisterMessage(TLRequest)

InternalServerError = _reflection.GeneratedProtocolMessageType('InternalServerError', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALSERVERERROR,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.InternalServerError)
  })
_sym_db.RegisterMessage(InternalServerError)

Ack = _reflection.GeneratedProtocolMessageType('Ack', (_message.Message,), {
  'DESCRIPTOR' : _ACK,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.Ack)
  })
_sym_db.RegisterMessage(Ack)

TLResponse = _reflection.GeneratedProtocolMessageType('TLResponse', (_message.Message,), {
  'DESCRIPTOR' : _TLRESPONSE,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.TLResponse)
  })
_sym_db.RegisterMessage(TLResponse)

ChunkHeader = _reflection.GeneratedProtocolMessageType('ChunkHeader', (_message.Message,), {
  'DESCRIPTOR' : _CHUNKHEADER,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.ChunkHeader)
  })
_sym_db.RegisterMessage(ChunkHeader)

ChunkData = _reflection.GeneratedProtocolMessageType('ChunkData', (_message.Message,), {
  'DESCRIPTOR' : _CHUNKDATA,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.ChunkData)
  })
_sym_db.RegisterMessage(ChunkData)

Chunk = _reflection.GeneratedProtocolMessageType('Chunk', (_message.Message,), {
  'DESCRIPTOR' : _CHUNK,
  '__module__' : 'routing_pb2'
  # @@protoc_insertion_point(class_scope:routing.Chunk)
  })
_sym_db.RegisterMessage(Chunk)


DESCRIPTOR._options = None

_TRANSPORTLAYER = _descriptor.ServiceDescriptor(
  name='TransportLayer',
  full_name='routing.TransportLayer',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1177,
  serialized_end=1295,
  methods=[
  _descriptor.MethodDescriptor(
    name='Send',
    full_name='routing.TransportLayer.Send',
    index=0,
    containing_service=None,
    input_type=_TLREQUEST,
    output_type=_TLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Stream',
    full_name='routing.TransportLayer.Stream',
    index=1,
    containing_service=None,
    input_type=_CHUNK,
    output_type=_TLRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRANSPORTLAYER)

DESCRIPTOR.services_by_name['TransportLayer'] = _TRANSPORTLAYER

# @@protoc_insertion_point(module_scope)



import string
import time
from typing import Mapping, Optional

from ..client import RClient
from ..const import DEFAULT_PHLO_LIMIT, DEFAULT_PHLO_PRICE
from ..crypto import PrivateKey
from ..pb.DeployServiceV1_pb2 import ListeningNameDataPayload as Data

CREATE_VAULT_RHO_TPL = """
new rl(`rho:registry:lookup`), RevVaultCh in {
  rl!(`rho:rchain:revVault`, *RevVaultCh) |
  for (@(_, RevVault) <- RevVaultCh) {
    @RevVault!("findOrCreateVault", "$addr", Nil)
  }
}
"""

BOND_RHO_TPL = """
new retCh, PoSCh, rl(`rho:registry:lookup`), stdout(`rho:io:stdout`) in {
  stdout!("About to lookup pos contract.") |
  rl!(`rho:rchain:pos`, *PoSCh) |
  for(@(_, PoS) <- PoSCh) {
    stdout!("About to bond") |
    @PoS!("bond", $amount, *retCh) |
    for ( @(_, message) <- retCh) {
      stdout!(message)
    }
  }
}
"""

GET_BALANCE_RHO_TPL = """
new rl(`rho:registry:lookup`), deployId(`rho:rchain:deployId`), RevVaultCh, vaultCh, balanceCh in {
  rl!(`rho:rchain:revVault`, *RevVaultCh) |
  for (@(_, RevVault) <- RevVaultCh) {
    @RevVault!("findOrCreate", "$addr", *vaultCh) |
    for (@(true, vault) <- vaultCh) {
      @vault!("balance", *balanceCh) |
      for (@balance <- balanceCh) {
        deployId!(balance)
      }
    }
  }
}
"""

TRANSFER_RHO_TPL = """
new rl(`rho:registry:lookup`), RevVaultCh, vaultCh, revVaultKeyCh, resultCh in {
  rl!(`rho:rchain:revVault`, *RevVaultCh) |
  for (@(_, RevVault) <- RevVaultCh) {
    @RevVault!("findOrCreate", "$from", *vaultCh) |
    @RevVault!("deployerAuthKey", *revVaultKeyCh) |
    for (@(true, vault) <- vaultCh; key <- revVaultKeyCh) {
      @vault!("transfer", "$to", $amount, *key, *resultCh) |
      for (_ <- resultCh) { Nil }
    }
  }
}
"""


class VaultAPIException(Exception):

    def _init__(self, message):
        super().__init__(message)


def render_contract_template(template: str, substitutions: Mapping[str, str]) -> str:
    return string.Template(template).substitute(substitutions)


class VaultAPI:

    def __init__(self, client: RClient, key: PrivateKey):
        self.client = client
        self.key = key

    def _get_addr(self, addr: Optional[str]) -> str:
        return addr or self.key.get_public_key().get_rev_address()

    def _deploy(self, contract: str, phlo_price: int, phlo_limit: int) -> str:
        timestamp_mill = int(time.time() * 1000)
        return self.client.deploy_with_vabn_filled(self.key, contract, phlo_price, phlo_limit, timestamp_mill)

    def deploy_create_vault(self, addr: Optional[str] = None, phlo_price: int = DEFAULT_PHLO_PRICE,
                            phlo_limit: int = DEFAULT_PHLO_LIMIT) -> str:
        contract = render_contract_template(
            CREATE_VAULT_RHO_TPL,
            {'addr': self._get_addr(addr)},
        )
        return self._deploy(contract, phlo_price, phlo_limit)

    def create_vault(self, phlo_price: int = DEFAULT_PHLO_PRICE, phlo_limit: int = DEFAULT_PHLO_LIMIT) -> None:
        self.deploy_create_vault(phlo_price=phlo_price, phlo_limit=phlo_limit)
        self.client.propose()

    def deploy_bond(self, amount, phlo_price: int = DEFAULT_PHLO_PRICE, phlo_limit=DEFAULT_PHLO_LIMIT) -> str:
        contract = render_contract_template(BOND_RHO_TPL, {'amount': amount})
        return self._deploy(contract, phlo_price, phlo_limit)

    def bond(self, amount=100, phlo_price: int = DEFAULT_PHLO_PRICE, phlo_limit: int = DEFAULT_PHLO_LIMIT) -> None:
        self.deploy_bond(amount, phlo_price, phlo_limit)
        self.client.propose()

    def deploy_get_balance(self, addr: Optional[str] = None, phlo_price: int = DEFAULT_PHLO_PRICE,
                           phlo_limit: int = DEFAULT_PHLO_LIMIT) -> str:
        contract = render_contract_template(
            GET_BALANCE_RHO_TPL,
            {'addr': self._get_addr(addr)},
        )
        return self._deploy(contract, phlo_price, phlo_limit)

    def get_balance_from_data(self, data: Data) -> int:
        return data.blockInfo[0].postBlockData[0].exprs[0].g_int

    def get_balance_from_deploy_id(self, deploy_id: str, depth: int = -1) -> int:
        data = self.client.get_data_at_deploy_id(deploy_id, depth=depth)
        if not data:
            raise VaultAPIException('No data at deployId')
        return self.get_balance_from_data(data)

    def get_balance(self, addr: Optional[str] = None, depth: int = -1, phlo_price: int = DEFAULT_PHLO_PRICE,
                    phlo_limit: int = DEFAULT_PHLO_LIMIT) -> int:
        deploy_id = self.deploy_get_balance(addr, phlo_price, phlo_limit)
        self.client.propose()
        return self.get_balance_from_deploy_id(deploy_id, depth=depth)

    def deploy_transfer(
            self, from_addr: Optional[str], to_addr: str, amount: int, phlo_price: int = DEFAULT_PHLO_PRICE,
            phlo_limit: int = DEFAULT_PHLO_LIMIT
    ) -> str:
        contract = render_contract_template(
            TRANSFER_RHO_TPL, {
                'from': self._get_addr(from_addr),
                'to': to_addr,
                'amount': str(amount)
            }
        )
        return self._deploy(contract, phlo_price, phlo_limit)

    def transfer(self, from_addr: Optional[str], to_addr: str, amount: int, phlo_price: int = DEFAULT_PHLO_PRICE,
                 phlo_limit: int = DEFAULT_PHLO_LIMIT) -> None:
        self.deploy_transfer(from_addr, to_addr, amount, phlo_price, phlo_limit)
        self.client.propose()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import CasperMessage_pb2 as CasperMessage__pb2
from . import DeployServiceCommon_pb2 as DeployServiceCommon__pb2
from . import DeployServiceV1_pb2 as DeployServiceV1__pb2


class DeployServiceStub(object):
  """Use `doDeploy` to queue deployments of Rholang code and then
  `ProposeServiceV2.propose` to make a new block with the results of running them
  all.

  To get results back, use `listenForDataAtName`.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.doDeploy = channel.unary_unary(
        '/casper.v1.DeployService/doDeploy',
        request_serializer=CasperMessage__pb2.DeployDataProto.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.DeployResponse.FromString,
        )
    self.getBlock = channel.unary_unary(
        '/casper.v1.DeployService/getBlock',
        request_serializer=DeployServiceCommon__pb2.BlockQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.BlockResponse.FromString,
        )
    self.visualizeDag = channel.unary_stream(
        '/casper.v1.DeployService/visualizeDag',
        request_serializer=DeployServiceCommon__pb2.VisualizeDagQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.VisualizeBlocksResponse.FromString,
        )
    self.machineVerifiableDag = channel.unary_unary(
        '/casper.v1.DeployService/machineVerifiableDag',
        request_serializer=DeployServiceCommon__pb2.MachineVerifyQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.MachineVerifyResponse.FromString,
        )
    self.showMainChain = channel.unary_stream(
        '/casper.v1.DeployService/showMainChain',
        request_serializer=DeployServiceCommon__pb2.BlocksQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.BlockInfoResponse.FromString,
        )
    self.getBlocks = channel.unary_stream(
        '/casper.v1.DeployService/getBlocks',
        request_serializer=DeployServiceCommon__pb2.BlocksQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.BlockInfoResponse.FromString,
        )
    self.listenForDataAtName = channel.unary_unary(
        '/casper.v1.DeployService/listenForDataAtName',
        request_serializer=DeployServiceCommon__pb2.DataAtNameQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.ListeningNameDataResponse.FromString,
        )
    self.listenForContinuationAtName = channel.unary_unary(
        '/casper.v1.DeployService/listenForContinuationAtName',
        request_serializer=DeployServiceCommon__pb2.ContinuationAtNameQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.ContinuationAtNameResponse.FromString,
        )
    self.findDeploy = channel.unary_unary(
        '/casper.v1.DeployService/findDeploy',
        request_serializer=DeployServiceCommon__pb2.FindDeployQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.FindDeployResponse.FromString,
        )
    self.previewPrivateNames = channel.unary_unary(
        '/casper.v1.DeployService/previewPrivateNames',
        request_serializer=DeployServiceCommon__pb2.PrivateNamePreviewQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.PrivateNamePreviewResponse.FromString,
        )
    self.lastFinalizedBlock = channel.unary_unary(
        '/casper.v1.DeployService/lastFinalizedBlock',
        request_serializer=DeployServiceCommon__pb2.LastFinalizedBlockQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.LastFinalizedBlockResponse.FromString,
        )
    self.isFinalized = channel.unary_unary(
        '/casper.v1.DeployService/isFinalized',
        request_serializer=DeployServiceCommon__pb2.IsFinalizedQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.IsFinalizedResponse.FromString,
        )
    self.bondStatus = channel.unary_unary(
        '/casper.v1.DeployService/bondStatus',
        request_serializer=DeployServiceCommon__pb2.BondStatusQuery.SerializeToString,
        response_deserializer=DeployServiceV1__pb2.BondStatusResponse.FromString,
        )


class DeployServiceServicer(object):
  """Use `doDeploy` to queue deployments of Rholang code and then
  `ProposeServiceV2.propose` to make a new block with the results of running them
  all.

  To get results back, use `listenForDataAtName`.
  """

  def doDeploy(self, request, context):
    """Queue deployment of Rholang code (or fail to parse).
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getBlock(self, request, context):
    """Get details about a particular block.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def visualizeDag(self, request, context):
    """Get dag
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def machineVerifiableDag(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def showMainChain(self, request, context):
    """Returns on success LightBlockInfo
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getBlocks(self, request, context):
    """Get a summary of blocks on the blockchain.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def listenForDataAtName(self, request, context):
    """Find data sent to a name.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def listenForContinuationAtName(self, request, context):
    """Find processes receiving on a name.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def findDeploy(self, request, context):
    """Find block containing a deploy.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def previewPrivateNames(self, request, context):
    """Preview new top-level unforgeable names (for example, to compute signatures over them).
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def lastFinalizedBlock(self, request, context):
    """Get details about a particular block.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def isFinalized(self, request, context):
    """Check if a given block is finalized.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def bondStatus(self, request, context):
    """Check if a given validator is bonded.
    Returns on success BondStatusResponse
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DeployServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'doDeploy': grpc.unary_unary_rpc_method_handler(
          servicer.doDeploy,
          request_deserializer=CasperMessage__pb2.DeployDataProto.FromString,
          response_serializer=DeployServiceV1__pb2.DeployResponse.SerializeToString,
      ),
      'getBlock': grpc.unary_unary_rpc_method_handler(
          servicer.getBlock,
          request_deserializer=DeployServiceCommon__pb2.BlockQuery.FromString,
          response_serializer=DeployServiceV1__pb2.BlockResponse.SerializeToString,
      ),
      'visualizeDag': grpc.unary_stream_rpc_method_handler(
          servicer.visualizeDag,
          request_deserializer=DeployServiceCommon__pb2.VisualizeDagQuery.FromString,
          response_serializer=DeployServiceV1__pb2.VisualizeBlocksResponse.SerializeToString,
      ),
      'machineVerifiableDag': grpc.unary_unary_rpc_method_handler(
          servicer.machineVerifiableDag,
          request_deserializer=DeployServiceCommon__pb2.MachineVerifyQuery.FromString,
          response_serializer=DeployServiceV1__pb2.MachineVerifyResponse.SerializeToString,
      ),
      'showMainChain': grpc.unary_stream_rpc_method_handler(
          servicer.showMainChain,
          request_deserializer=DeployServiceCommon__pb2.BlocksQuery.FromString,
          response_serializer=DeployServiceV1__pb2.BlockInfoResponse.SerializeToString,
      ),
      'getBlocks': grpc.unary_stream_rpc_method_handler(
          servicer.getBlocks,
          request_deserializer=DeployServiceCommon__pb2.BlocksQuery.FromString,
          response_serializer=DeployServiceV1__pb2.BlockInfoResponse.SerializeToString,
      ),
      'listenForDataAtName': grpc.unary_unary_rpc_method_handler(
          servicer.listenForDataAtName,
          request_deserializer=DeployServiceCommon__pb2.DataAtNameQuery.FromString,
          response_serializer=DeployServiceV1__pb2.ListeningNameDataResponse.SerializeToString,
      ),
      'listenForContinuationAtName': grpc.unary_unary_rpc_method_handler(
          servicer.listenForContinuationAtName,
          request_deserializer=DeployServiceCommon__pb2.ContinuationAtNameQuery.FromString,
          response_serializer=DeployServiceV1__pb2.ContinuationAtNameResponse.SerializeToString,
      ),
      'findDeploy': grpc.unary_unary_rpc_method_handler(
          servicer.findDeploy,
          request_deserializer=DeployServiceCommon__pb2.FindDeployQuery.FromString,
          response_serializer=DeployServiceV1__pb2.FindDeployResponse.SerializeToString,
      ),
      'previewPrivateNames': grpc.unary_unary_rpc_method_handler(
          servicer.previewPrivateNames,
          request_deserializer=DeployServiceCommon__pb2.PrivateNamePreviewQuery.FromString,
          response_serializer=DeployServiceV1__pb2.PrivateNamePreviewResponse.SerializeToString,
      ),
      'lastFinalizedBlock': grpc.unary_unary_rpc_method_handler(
          servicer.lastFinalizedBlock,
          request_deserializer=DeployServiceCommon__pb2.LastFinalizedBlockQuery.FromString,
          response_serializer=DeployServiceV1__pb2.LastFinalizedBlockResponse.SerializeToString,
      ),
      'isFinalized': grpc.unary_unary_rpc_method_handler(
          servicer.isFinalized,
          request_deserializer=DeployServiceCommon__pb2.IsFinalizedQuery.FromString,
          response_serializer=DeployServiceV1__pb2.IsFinalizedResponse.SerializeToString,
      ),
      'bondStatus': grpc.unary_unary_rpc_method_handler(
          servicer.bondStatus,
          request_deserializer=DeployServiceCommon__pb2.BondStatusQuery.FromString,
          response_serializer=DeployServiceV1__pb2.BondStatusResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'casper.v1.DeployService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ProposeServiceV1.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ServiceError_pb2 as ServiceError__pb2
from . import ProposeServiceCommon_pb2 as ProposeServiceCommon__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ProposeServiceV1.proto',
  package='casper.v1',
  syntax='proto3',
  serialized_options=_b('\342?,\n&coop.rchain.casper.protocol.propose.v1\020\001(\001'),
  serialized_pb=_b('\n\x16ProposeServiceV1.proto\x12\tcasper.v1\x1a\x12ServiceError.proto\x1a\x1aProposeServiceCommon.proto\x1a\x15scalapb/scalapb.proto\"N\n\x0fProposeResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x10\n\x06result\x18\x02 \x01(\tH\x00\x42\t\n\x07message2[\n\x0eProposeService\x12I\n\x07propose\x12 .casper.PrintUnmatchedSendsQuery\x1a\x1a.casper.v1.ProposeResponse\"\x00\x42/\xe2?,\n&coop.rchain.casper.protocol.propose.v1\x10\x01(\x01\x62\x06proto3')
  ,
  dependencies=[ServiceError__pb2.DESCRIPTOR,ProposeServiceCommon__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_PROPOSERESPONSE = _descriptor.Descriptor(
  name='ProposeResponse',
  full_name='casper.v1.ProposeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.ProposeResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='casper.v1.ProposeResponse.result', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.ProposeResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=108,
  serialized_end=186,
)

_PROPOSERESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_PROPOSERESPONSE.oneofs_by_name['message'].fields.append(
  _PROPOSERESPONSE.fields_by_name['error'])
_PROPOSERESPONSE.fields_by_name['error'].containing_oneof = _PROPOSERESPONSE.oneofs_by_name['message']
_PROPOSERESPONSE.oneofs_by_name['message'].fields.append(
  _PROPOSERESPONSE.fields_by_name['result'])
_PROPOSERESPONSE.fields_by_name['result'].containing_oneof = _PROPOSERESPONSE.oneofs_by_name['message']
DESCRIPTOR.message_types_by_name['ProposeResponse'] = _PROPOSERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProposeResponse = _reflection.GeneratedProtocolMessageType('ProposeResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSERESPONSE,
  '__module__' : 'ProposeServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.ProposeResponse)
  })
_sym_db.RegisterMessage(ProposeResponse)


DESCRIPTOR._options = None

_PROPOSESERVICE = _descriptor.ServiceDescriptor(
  name='ProposeService',
  full_name='casper.v1.ProposeService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=188,
  serialized_end=279,
  methods=[
  _descriptor.MethodDescriptor(
    name='propose',
    full_name='casper.v1.ProposeService.propose',
    index=0,
    containing_service=None,
    input_type=ProposeServiceCommon__pb2._PRINTUNMATCHEDSENDSQUERY,
    output_type=_PROPOSERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROPOSESERVICE)

DESCRIPTOR.services_by_name['ProposeService'] = _PROPOSESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CasperMessage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from . import RhoTypes_pb2 as RhoTypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='CasperMessage.proto',
  package='casper',
  syntax='proto3',
  serialized_options=_b('\342?B\n\033coop.rchain.casper.protocol\020\001\"\037sealed trait CasperMessageProto(\001'),
  serialized_pb=_b('\n\x13\x43\x61sperMessage.proto\x12\x06\x63\x61sper\x1a\x15scalapb/scalapb.proto\x1a\x0eRhoTypes.proto\"=\n\x14HasBlockRequestProto\x12\x0c\n\x04hash\x18\x01 \x01(\x0c:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\"6\n\rHasBlockProto\x12\x0c\n\x04hash\x18\x01 \x01(\x0c:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\":\n\x11\x42lockRequestProto\x12\x0c\n\x04hash\x18\x01 \x01(\x0c:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\"4\n\x19\x46orkChoiceTipRequestProto:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\"v\n\x1b\x41pprovedBlockCandidateProto\x12(\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x19.casper.BlockMessageProto\x12\x14\n\x0crequiredSigs\x18\x02 \x01(\x05:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\"\x8c\x01\n\x14UnapprovedBlockProto\x12\x36\n\tcandidate\x18\x01 \x01(\x0b\x32#.casper.ApprovedBlockCandidateProto\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\">\n\tSignature\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\x12\x11\n\talgorithm\x18\x02 \x01(\t\x12\x0b\n\x03sig\x18\x03 \x01(\x0c\"\x85\x01\n\x12\x42lockApprovalProto\x12\x36\n\tcandidate\x18\x01 \x01(\x0b\x32#.casper.ApprovedBlockCandidateProto\x12\x1e\n\x03sig\x18\x02 \x01(\x0b\x32\x11.casper.Signature:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\"\x86\x01\n\x12\x41pprovedBlockProto\x12\x36\n\tcandidate\x18\x01 \x01(\x0b\x32#.casper.ApprovedBlockCandidateProto\x12\x1f\n\x04sigs\x18\x02 \x03(\x0b\x32\x11.casper.Signature:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\"H\n\x19\x41pprovedBlockRequestProto\x12\x12\n\nidentifier\x18\x01 \x01(\t:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\"c\n\x1dNoApprovedBlockAvailableProto\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x15\n\rnodeIdentifer\x18\x02 \x01(\t:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\"\xa1\x02\n\x11\x42lockMessageProto\x12\x11\n\tblockHash\x18\x01 \x01(\x0c\x12#\n\x06header\x18\x02 \x01(\x0b\x32\x13.casper.HeaderProto\x12\x1f\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x11.casper.BodyProto\x12\x32\n\x0ejustifications\x18\x04 \x03(\x0b\x32\x1a.casper.JustificationProto\x12\x0e\n\x06sender\x18\x05 \x01(\x0c\x12\x0e\n\x06seqNum\x18\x06 \x01(\x05\x12\x0b\n\x03sig\x18\x07 \x01(\x0c\x12\x14\n\x0csigAlgorithm\x18\x08 \x01(\t\x12\x0f\n\x07shardId\x18\t \x01(\t\x12\x12\n\nextraBytes\x18\n \x01(\x0c:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\"T\n\x15\x42lockHashMessageProto\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x14\n\x0c\x62lockCreator\x18\x02 \x01(\x0c:\x17\xe2?\x14\n\x12\x43\x61sperMessageProto\"\xdb\x02\n\x15\x42lockMetadataInternal\x12\x11\n\tblockHash\x18\x01 \x01(\x0c\x12/\n\x07parents\x18\x02 \x03(\x0c\x42\x1e\xe2?\x1b\x1a\x19\x63ollection.immutable.List\x12\x0e\n\x06sender\x18\x03 \x01(\x0c\x12R\n\x0ejustifications\x18\x04 \x03(\x0b\x32\x1a.casper.JustificationProtoB\x1e\xe2?\x1b\x1a\x19\x63ollection.immutable.List\x12@\n\x05\x62onds\x18\x05 \x03(\x0b\x32\x11.casper.BondProtoB\x1e\xe2?\x1b\x1a\x19\x63ollection.immutable.List\x12\x10\n\x08\x62lockNum\x18\x06 \x01(\x03\x12\x0e\n\x06seqNum\x18\x07 \x01(\x05\x12\x0f\n\x07invalid\x18\x08 \x01(\x08:%\xe2?\"\" coop.rchain.models.BlockMetadata\"^\n\x0bHeaderProto\x12\x17\n\x0fparentsHashList\x18\x01 \x03(\x0c\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\x12\x0f\n\x07version\x18\x06 \x01(\x03\x12\x12\n\nextraBytes\x18\x07 \x01(\x0c\"\xac\x01\n\x0f\x44\x65ployDataProto\x12\x10\n\x08\x64\x65ployer\x18\x01 \x01(\x0c\x12\x0c\n\x04term\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x0b\n\x03sig\x18\x04 \x01(\x0c\x12\x14\n\x0csigAlgorithm\x18\x05 \x01(\t\x12\x11\n\tphloPrice\x18\x07 \x01(\x03\x12\x11\n\tphloLimit\x18\x08 \x01(\x03\x12\x1d\n\x15validAfterBlockNumber\x18\n \x01(\x03\"\xa8\x01\n\x14ProcessedDeployProto\x12\'\n\x06\x64\x65ploy\x18\x01 \x01(\x0b\x32\x17.casper.DeployDataProto\x12\x14\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x06.PCost\x12%\n\tdeployLog\x18\x03 \x03(\x0b\x32\x12.casper.EventProto\x12\x0f\n\x07\x65rrored\x18\x05 \x01(\x08\x12\x19\n\x11systemDeployError\x18\x06 \x01(\t\"U\n\x1aProcessedSystemDeployProto\x12%\n\tdeployLog\x18\x01 \x03(\x0b\x32\x12.casper.EventProto\x12\x10\n\x08\x65rrorMsg\x18\x02 \x01(\t\"w\n\tBodyProto\x12\'\n\x05state\x18\x01 \x01(\x0b\x32\x18.casper.RChainStateProto\x12-\n\x07\x64\x65ploys\x18\x02 \x03(\x0b\x32\x1c.casper.ProcessedDeployProto\x12\x12\n\nextraBytes\x18\x03 \x01(\x0c\"@\n\x12JustificationProto\x12\x11\n\tvalidator\x18\x01 \x01(\x0c\x12\x17\n\x0flatestBlockHash\x18\x02 \x01(\x0c\"v\n\x10RChainStateProto\x12\x14\n\x0cpreStateHash\x18\x01 \x01(\x0c\x12\x15\n\rpostStateHash\x18\x02 \x01(\x0c\x12 \n\x05\x62onds\x18\x03 \x03(\x0b\x32\x11.casper.BondProto\x12\x13\n\x0b\x62lockNumber\x18\x04 \x01(\x03\"\xa2\x01\n\nEventProto\x12,\n\x07produce\x18\x01 \x01(\x0b\x32\x19.casper.ProduceEventProtoH\x00\x12,\n\x07\x63onsume\x18\x02 \x01(\x0b\x32\x19.casper.ConsumeEventProtoH\x00\x12&\n\x04\x63omm\x18\x03 \x01(\x0b\x32\x16.casper.CommEventProtoH\x00\x42\x10\n\x0e\x65vent_instance\"b\n\x11ProduceEventProto\x12\x14\n\x0c\x63hannelsHash\x18\x01 \x01(\x0c\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\x12\x12\n\npersistent\x18\x03 \x01(\x08\x12\x15\n\rtimesRepeated\x18\x04 \x01(\x05\"M\n\x11\x43onsumeEventProto\x12\x16\n\x0e\x63hannelsHashes\x18\x01 \x03(\x0c\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\x12\x12\n\npersistent\x18\x03 \x01(\x08\"\x8b\x01\n\x0e\x43ommEventProto\x12*\n\x07\x63onsume\x18\x01 \x01(\x0b\x32\x19.casper.ConsumeEventProto\x12+\n\x08produces\x18\x02 \x03(\x0b\x32\x19.casper.ProduceEventProto\x12 \n\x05peeks\x18\x03 \x03(\x0b\x32\x11.casper.PeekProto\"!\n\tPeekProto\x12\x14\n\x0c\x63hannelIndex\x18\x01 \x01(\x05\"-\n\tBondProto\x12\x11\n\tvalidator\x18\x01 \x01(\x0c\x12\r\n\x05stake\x18\x02 \x01(\x03\x42\x45\xe2?B\n\x1b\x63oop.rchain.casper.protocol\x10\x01\"\x1fsealed trait CasperMessageProto(\x01\x62\x06proto3')
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,RhoTypes__pb2.DESCRIPTOR,])




_HASBLOCKREQUESTPROTO = _descriptor.Descriptor(
  name='HasBlockRequestProto',
  full_name='casper.HasBlockRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='casper.HasBlockRequestProto.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=131,
)


_HASBLOCKPROTO = _descriptor.Descriptor(
  name='HasBlockProto',
  full_name='casper.HasBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='casper.HasBlockProto.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=187,
)


_BLOCKREQUESTPROTO = _descriptor.Descriptor(
  name='BlockRequestProto',
  full_name='casper.BlockRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='casper.BlockRequestProto.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=247,
)


_FORKCHOICETIPREQUESTPROTO = _descriptor.Descriptor(
  name='ForkChoiceTipRequestProto',
  full_name='casper.ForkChoiceTipRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=301,
)


_APPROVEDBLOCKCANDIDATEPROTO = _descriptor.Descriptor(
  name='ApprovedBlockCandidateProto',
  full_name='casper.ApprovedBlockCandidateProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='casper.ApprovedBlockCandidateProto.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requiredSigs', full_name='casper.ApprovedBlockCandidateProto.requiredSigs', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=421,
)


_UNAPPROVEDBLOCKPROTO = _descriptor.Descriptor(
  name='UnapprovedBlockProto',
  full_name='casper.UnapprovedBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidate', full_name='casper.UnapprovedBlockProto.candidate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='casper.UnapprovedBlockProto.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='casper.UnapprovedBlockProto.duration', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=564,
)


_SIGNATURE = _descriptor.Descriptor(
  name='Signature',
  full_name='casper.Signature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='publicKey', full_name='casper.Signature.publicKey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='casper.Signature.algorithm', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sig', full_name='casper.Signature.sig', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=628,
)


_BLOCKAPPROVALPROTO = _descriptor.Descriptor(
  name='BlockApprovalProto',
  full_name='casper.BlockApprovalProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidate', full_name='casper.BlockApprovalProto.candidate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sig', full_name='casper.BlockApprovalProto.sig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=764,
)


_APPROVEDBLOCKPROTO = _descriptor.Descriptor(
  name='ApprovedBlockProto',
  full_name='casper.ApprovedBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidate', full_name='casper.ApprovedBlockProto.candidate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigs', full_name='casper.ApprovedBlockProto.sigs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=901,
)


_APPROVEDBLOCKREQUESTPROTO = _descriptor.Descriptor(
  name='ApprovedBlockRequestProto',
  full_name='casper.ApprovedBlockRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='casper.ApprovedBlockRequestProto.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=975,
)


_NOAPPROVEDBLOCKAVAILABLEPROTO = _descriptor.Descriptor(
  name='NoApprovedBlockAvailableProto',
  full_name='casper.NoApprovedBlockAvailableProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='casper.NoApprovedBlockAvailableProto.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodeIdentifer', full_name='casper.NoApprovedBlockAvailableProto.nodeIdentifer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=977,
  serialized_end=1076,
)


_BLOCKMESSAGEPROTO = _descriptor.Descriptor(
  name='BlockMessageProto',
  full_name='casper.BlockMessageProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHash', full_name='casper.BlockMessageProto.blockHash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='casper.BlockMessageProto.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='casper.BlockMessageProto.body', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='justifications', full_name='casper.BlockMessageProto.justifications', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender', full_name='casper.BlockMessageProto.sender', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNum', full_name='casper.BlockMessageProto.seqNum', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sig', full_name='casper.BlockMessageProto.sig', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigAlgorithm', full_name='casper.BlockMessageProto.sigAlgorithm', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shardId', full_name='casper.BlockMessageProto.shardId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extraBytes', full_name='casper.BlockMessageProto.extraBytes', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1079,
  serialized_end=1368,
)


_BLOCKHASHMESSAGEPROTO = _descriptor.Descriptor(
  name='BlockHashMessageProto',
  full_name='casper.BlockHashMessageProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='casper.BlockHashMessageProto.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockCreator', full_name='casper.BlockHashMessageProto.blockCreator', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\024\n\022CasperMessageProto'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1370,
  serialized_end=1454,
)


_BLOCKMETADATAINTERNAL = _descriptor.Descriptor(
  name='BlockMetadataInternal',
  full_name='casper.BlockMetadataInternal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHash', full_name='casper.BlockMetadataInternal.blockHash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parents', full_name='casper.BlockMetadataInternal.parents', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\033\032\031collection.immutable.List'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender', full_name='casper.BlockMetadataInternal.sender', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='justifications', full_name='casper.BlockMetadataInternal.justifications', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\033\032\031collection.immutable.List'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bonds', full_name='casper.BlockMetadataInternal.bonds', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\342?\033\032\031collection.immutable.List'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockNum', full_name='casper.BlockMetadataInternal.blockNum', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNum', full_name='casper.BlockMetadataInternal.seqNum', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalid', full_name='casper.BlockMetadataInternal.invalid', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\"\" coop.rchain.models.BlockMetadata'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1457,
  serialized_end=1804,
)


_HEADERPROTO = _descriptor.Descriptor(
  name='HeaderProto',
  full_name='casper.HeaderProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parentsHashList', full_name='casper.HeaderProto.parentsHashList', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='casper.HeaderProto.timestamp', index=1,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='casper.HeaderProto.version', index=2,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extraBytes', full_name='casper.HeaderProto.extraBytes', index=3,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1806,
  serialized_end=1900,
)


_DEPLOYDATAPROTO = _descriptor.Descriptor(
  name='DeployDataProto',
  full_name='casper.DeployDataProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployer', full_name='casper.DeployDataProto.deployer', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='term', full_name='casper.DeployDataProto.term', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='casper.DeployDataProto.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sig', full_name='casper.DeployDataProto.sig', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigAlgorithm', full_name='casper.DeployDataProto.sigAlgorithm', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phloPrice', full_name='casper.DeployDataProto.phloPrice', index=5,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phloLimit', full_name='casper.DeployDataProto.phloLimit', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validAfterBlockNumber', full_name='casper.DeployDataProto.validAfterBlockNumber', index=7,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1903,
  serialized_end=2075,
)


_PROCESSEDDEPLOYPROTO = _descriptor.Descriptor(
  name='ProcessedDeployProto',
  full_name='casper.ProcessedDeployProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy', full_name='casper.ProcessedDeployProto.deploy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost', full_name='casper.ProcessedDeployProto.cost', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployLog', full_name='casper.ProcessedDeployProto.deployLog', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errored', full_name='casper.ProcessedDeployProto.errored', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='systemDeployError', full_name='casper.ProcessedDeployProto.systemDeployError', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2078,
  serialized_end=2246,
)


_PROCESSEDSYSTEMDEPLOYPROTO = _descriptor.Descriptor(
  name='ProcessedSystemDeployProto',
  full_name='casper.ProcessedSystemDeployProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployLog', full_name='casper.ProcessedSystemDeployProto.deployLog', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorMsg', full_name='casper.ProcessedSystemDeployProto.errorMsg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2248,
  serialized_end=2333,
)


_BODYPROTO = _descriptor.Descriptor(
  name='BodyProto',
  full_name='casper.BodyProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='casper.BodyProto.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploys', full_name='casper.BodyProto.deploys', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extraBytes', full_name='casper.BodyProto.extraBytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2335,
  serialized_end=2454,
)


_JUSTIFICATIONPROTO = _descriptor.Descriptor(
  name='JustificationProto',
  full_name='casper.JustificationProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='casper.JustificationProto.validator', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latestBlockHash', full_name='casper.JustificationProto.latestBlockHash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2456,
  serialized_end=2520,
)


_RCHAINSTATEPROTO = _descriptor.Descriptor(
  name='RChainStateProto',
  full_name='casper.RChainStateProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='preStateHash', full_name='casper.RChainStateProto.preStateHash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postStateHash', full_name='casper.RChainStateProto.postStateHash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bonds', full_name='casper.RChainStateProto.bonds', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockNumber', full_name='casper.RChainStateProto.blockNumber', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2522,
  serialized_end=2640,
)


_EVENTPROTO = _descriptor.Descriptor(
  name='EventProto',
  full_name='casper.EventProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='produce', full_name='casper.EventProto.produce', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consume', full_name='casper.EventProto.consume', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comm', full_name='casper.EventProto.comm', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event_instance', full_name='casper.EventProto.event_instance',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2643,
  serialized_end=2805,
)


_PRODUCEEVENTPROTO = _descriptor.Descriptor(
  name='ProduceEventProto',
  full_name='casper.ProduceEventProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channelsHash', full_name='casper.ProduceEventProto.channelsHash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='casper.ProduceEventProto.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='casper.ProduceEventProto.persistent', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timesRepeated', full_name='casper.ProduceEventProto.timesRepeated', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2807,
  serialized_end=2905,
)


_CONSUMEEVENTPROTO = _descriptor.Descriptor(
  name='ConsumeEventProto',
  full_name='casper.ConsumeEventProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channelsHashes', full_name='casper.ConsumeEventProto.channelsHashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='casper.ConsumeEventProto.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='casper.ConsumeEventProto.persistent', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2907,
  serialized_end=2984,
)


_COMMEVENTPROTO = _descriptor.Descriptor(
  name='CommEventProto',
  full_name='casper.CommEventProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='consume', full_name='casper.CommEventProto.consume', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='produces', full_name='casper.CommEventProto.produces', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peeks', full_name='casper.CommEventProto.peeks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2987,
  serialized_end=3126,
)


_PEEKPROTO = _descriptor.Descriptor(
  name='PeekProto',
  full_name='casper.PeekProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channelIndex', full_name='casper.PeekProto.channelIndex', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3128,
  serialized_end=3161,
)


_BONDPROTO = _descriptor.Descriptor(
  name='BondProto',
  full_name='casper.BondProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='casper.BondProto.validator', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stake', full_name='casper.BondProto.stake', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3163,
  serialized_end=3208,
)

_APPROVEDBLOCKCANDIDATEPROTO.fields_by_name['block'].message_type = _BLOCKMESSAGEPROTO
_UNAPPROVEDBLOCKPROTO.fields_by_name['candidate'].message_type = _APPROVEDBLOCKCANDIDATEPROTO
_BLOCKAPPROVALPROTO.fields_by_name['candidate'].message_type = _APPROVEDBLOCKCANDIDATEPROTO
_BLOCKAPPROVALPROTO.fields_by_name['sig'].message_type = _SIGNATURE
_APPROVEDBLOCKPROTO.fields_by_name['candidate'].message_type = _APPROVEDBLOCKCANDIDATEPROTO
_APPROVEDBLOCKPROTO.fields_by_name['sigs'].message_type = _SIGNATURE
_BLOCKMESSAGEPROTO.fields_by_name['header'].message_type = _HEADERPROTO
_BLOCKMESSAGEPROTO.fields_by_name['body'].message_type = _BODYPROTO
_BLOCKMESSAGEPROTO.fields_by_name['justifications'].message_type = _JUSTIFICATIONPROTO
_BLOCKMETADATAINTERNAL.fields_by_name['justifications'].message_type = _JUSTIFICATIONPROTO
_BLOCKMETADATAINTERNAL.fields_by_name['bonds'].message_type = _BONDPROTO
_PROCESSEDDEPLOYPROTO.fields_by_name['deploy'].message_type = _DEPLOYDATAPROTO
_PROCESSEDDEPLOYPROTO.fields_by_name['cost'].message_type = RhoTypes__pb2._PCOST
_PROCESSEDDEPLOYPROTO.fields_by_name['deployLog'].message_type = _EVENTPROTO
_PROCESSEDSYSTEMDEPLOYPROTO.fields_by_name['deployLog'].message_type = _EVENTPROTO
_BODYPROTO.fields_by_name['state'].message_type = _RCHAINSTATEPROTO
_BODYPROTO.fields_by_name['deploys'].message_type = _PROCESSEDDEPLOYPROTO
_RCHAINSTATEPROTO.fields_by_name['bonds'].message_type = _BONDPROTO
_EVENTPROTO.fields_by_name['produce'].message_type = _PRODUCEEVENTPROTO
_EVENTPROTO.fields_by_name['consume'].message_type = _CONSUMEEVENTPROTO
_EVENTPROTO.fields_by_name['comm'].message_type = _COMMEVENTPROTO
_EVENTPROTO.oneofs_by_name['event_instance'].fields.append(
  _EVENTPROTO.fields_by_name['produce'])
_EVENTPROTO.fields_by_name['produce'].containing_oneof = _EVENTPROTO.oneofs_by_name['event_instance']
_EVENTPROTO.oneofs_by_name['event_instance'].fields.append(
  _EVENTPROTO.fields_by_name['consume'])
_EVENTPROTO.fields_by_name['consume'].containing_oneof = _EVENTPROTO.oneofs_by_name['event_instance']
_EVENTPROTO.oneofs_by_name['event_instance'].fields.append(
  _EVENTPROTO.fields_by_name['comm'])
_EVENTPROTO.fields_by_name['comm'].containing_oneof = _EVENTPROTO.oneofs_by_name['event_instance']
_COMMEVENTPROTO.fields_by_name['consume'].message_type = _CONSUMEEVENTPROTO
_COMMEVENTPROTO.fields_by_name['produces'].message_type = _PRODUCEEVENTPROTO
_COMMEVENTPROTO.fields_by_name['peeks'].message_type = _PEEKPROTO
DESCRIPTOR.message_types_by_name['HasBlockRequestProto'] = _HASBLOCKREQUESTPROTO
DESCRIPTOR.message_types_by_name['HasBlockProto'] = _HASBLOCKPROTO
DESCRIPTOR.message_types_by_name['BlockRequestProto'] = _BLOCKREQUESTPROTO
DESCRIPTOR.message_types_by_name['ForkChoiceTipRequestProto'] = _FORKCHOICETIPREQUESTPROTO
DESCRIPTOR.message_types_by_name['ApprovedBlockCandidateProto'] = _APPROVEDBLOCKCANDIDATEPROTO
DESCRIPTOR.message_types_by_name['UnapprovedBlockProto'] = _UNAPPROVEDBLOCKPROTO
DESCRIPTOR.message_types_by_name['Signature'] = _SIGNATURE
DESCRIPTOR.message_types_by_name['BlockApprovalProto'] = _BLOCKAPPROVALPROTO
DESCRIPTOR.message_types_by_name['ApprovedBlockProto'] = _APPROVEDBLOCKPROTO
DESCRIPTOR.message_types_by_name['ApprovedBlockRequestProto'] = _APPROVEDBLOCKREQUESTPROTO
DESCRIPTOR.message_types_by_name['NoApprovedBlockAvailableProto'] = _NOAPPROVEDBLOCKAVAILABLEPROTO
DESCRIPTOR.message_types_by_name['BlockMessageProto'] = _BLOCKMESSAGEPROTO
DESCRIPTOR.message_types_by_name['BlockHashMessageProto'] = _BLOCKHASHMESSAGEPROTO
DESCRIPTOR.message_types_by_name['BlockMetadataInternal'] = _BLOCKMETADATAINTERNAL
DESCRIPTOR.message_types_by_name['HeaderProto'] = _HEADERPROTO
DESCRIPTOR.message_types_by_name['DeployDataProto'] = _DEPLOYDATAPROTO
DESCRIPTOR.message_types_by_name['ProcessedDeployProto'] = _PROCESSEDDEPLOYPROTO
DESCRIPTOR.message_types_by_name['ProcessedSystemDeployProto'] = _PROCESSEDSYSTEMDEPLOYPROTO
DESCRIPTOR.message_types_by_name['BodyProto'] = _BODYPROTO
DESCRIPTOR.message_types_by_name['JustificationProto'] = _JUSTIFICATIONPROTO
DESCRIPTOR.message_types_by_name['RChainStateProto'] = _RCHAINSTATEPROTO
DESCRIPTOR.message_types_by_name['EventProto'] = _EVENTPROTO
DESCRIPTOR.message_types_by_name['ProduceEventProto'] = _PRODUCEEVENTPROTO
DESCRIPTOR.message_types_by_name['ConsumeEventProto'] = _CONSUMEEVENTPROTO
DESCRIPTOR.message_types_by_name['CommEventProto'] = _COMMEVENTPROTO
DESCRIPTOR.message_types_by_name['PeekProto'] = _PEEKPROTO
DESCRIPTOR.message_types_by_name['BondProto'] = _BONDPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HasBlockRequestProto = _reflection.GeneratedProtocolMessageType('HasBlockRequestProto', (_message.Message,), {
  'DESCRIPTOR' : _HASBLOCKREQUESTPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.HasBlockRequestProto)
  })
_sym_db.RegisterMessage(HasBlockRequestProto)

HasBlockProto = _reflection.GeneratedProtocolMessageType('HasBlockProto', (_message.Message,), {
  'DESCRIPTOR' : _HASBLOCKPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.HasBlockProto)
  })
_sym_db.RegisterMessage(HasBlockProto)

BlockRequestProto = _reflection.GeneratedProtocolMessageType('BlockRequestProto', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKREQUESTPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.BlockRequestProto)
  })
_sym_db.RegisterMessage(BlockRequestProto)

ForkChoiceTipRequestProto = _reflection.GeneratedProtocolMessageType('ForkChoiceTipRequestProto', (_message.Message,), {
  'DESCRIPTOR' : _FORKCHOICETIPREQUESTPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.ForkChoiceTipRequestProto)
  })
_sym_db.RegisterMessage(ForkChoiceTipRequestProto)

ApprovedBlockCandidateProto = _reflection.GeneratedProtocolMessageType('ApprovedBlockCandidateProto', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEDBLOCKCANDIDATEPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.ApprovedBlockCandidateProto)
  })
_sym_db.RegisterMessage(ApprovedBlockCandidateProto)

UnapprovedBlockProto = _reflection.GeneratedProtocolMessageType('UnapprovedBlockProto', (_message.Message,), {
  'DESCRIPTOR' : _UNAPPROVEDBLOCKPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.UnapprovedBlockProto)
  })
_sym_db.RegisterMessage(UnapprovedBlockProto)

Signature = _reflection.GeneratedProtocolMessageType('Signature', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATURE,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.Signature)
  })
_sym_db.RegisterMessage(Signature)

BlockApprovalProto = _reflection.GeneratedProtocolMessageType('BlockApprovalProto', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKAPPROVALPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.BlockApprovalProto)
  })
_sym_db.RegisterMessage(BlockApprovalProto)

ApprovedBlockProto = _reflection.GeneratedProtocolMessageType('ApprovedBlockProto', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEDBLOCKPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.ApprovedBlockProto)
  })
_sym_db.RegisterMessage(ApprovedBlockProto)

ApprovedBlockRequestProto = _reflection.GeneratedProtocolMessageType('ApprovedBlockRequestProto', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEDBLOCKREQUESTPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.ApprovedBlockRequestProto)
  })
_sym_db.RegisterMessage(ApprovedBlockRequestProto)

NoApprovedBlockAvailableProto = _reflection.GeneratedProtocolMessageType('NoApprovedBlockAvailableProto', (_message.Message,), {
  'DESCRIPTOR' : _NOAPPROVEDBLOCKAVAILABLEPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.NoApprovedBlockAvailableProto)
  })
_sym_db.RegisterMessage(NoApprovedBlockAvailableProto)

BlockMessageProto = _reflection.GeneratedProtocolMessageType('BlockMessageProto', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKMESSAGEPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.BlockMessageProto)
  })
_sym_db.RegisterMessage(BlockMessageProto)

BlockHashMessageProto = _reflection.GeneratedProtocolMessageType('BlockHashMessageProto', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKHASHMESSAGEPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.BlockHashMessageProto)
  })
_sym_db.RegisterMessage(BlockHashMessageProto)

BlockMetadataInternal = _reflection.GeneratedProtocolMessageType('BlockMetadataInternal', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKMETADATAINTERNAL,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.BlockMetadataInternal)
  })
_sym_db.RegisterMessage(BlockMetadataInternal)

HeaderProto = _reflection.GeneratedProtocolMessageType('HeaderProto', (_message.Message,), {
  'DESCRIPTOR' : _HEADERPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.HeaderProto)
  })
_sym_db.RegisterMessage(HeaderProto)

DeployDataProto = _reflection.GeneratedProtocolMessageType('DeployDataProto', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYDATAPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.DeployDataProto)
  })
_sym_db.RegisterMessage(DeployDataProto)

ProcessedDeployProto = _reflection.GeneratedProtocolMessageType('ProcessedDeployProto', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSEDDEPLOYPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.ProcessedDeployProto)
  })
_sym_db.RegisterMessage(ProcessedDeployProto)

ProcessedSystemDeployProto = _reflection.GeneratedProtocolMessageType('ProcessedSystemDeployProto', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSEDSYSTEMDEPLOYPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.ProcessedSystemDeployProto)
  })
_sym_db.RegisterMessage(ProcessedSystemDeployProto)

BodyProto = _reflection.GeneratedProtocolMessageType('BodyProto', (_message.Message,), {
  'DESCRIPTOR' : _BODYPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.BodyProto)
  })
_sym_db.RegisterMessage(BodyProto)

JustificationProto = _reflection.GeneratedProtocolMessageType('JustificationProto', (_message.Message,), {
  'DESCRIPTOR' : _JUSTIFICATIONPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.JustificationProto)
  })
_sym_db.RegisterMessage(JustificationProto)

RChainStateProto = _reflection.GeneratedProtocolMessageType('RChainStateProto', (_message.Message,), {
  'DESCRIPTOR' : _RCHAINSTATEPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.RChainStateProto)
  })
_sym_db.RegisterMessage(RChainStateProto)

EventProto = _reflection.GeneratedProtocolMessageType('EventProto', (_message.Message,), {
  'DESCRIPTOR' : _EVENTPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.EventProto)
  })
_sym_db.RegisterMessage(EventProto)

ProduceEventProto = _reflection.GeneratedProtocolMessageType('ProduceEventProto', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCEEVENTPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.ProduceEventProto)
  })
_sym_db.RegisterMessage(ProduceEventProto)

ConsumeEventProto = _reflection.GeneratedProtocolMessageType('ConsumeEventProto', (_message.Message,), {
  'DESCRIPTOR' : _CONSUMEEVENTPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.ConsumeEventProto)
  })
_sym_db.RegisterMessage(ConsumeEventProto)

CommEventProto = _reflection.GeneratedProtocolMessageType('CommEventProto', (_message.Message,), {
  'DESCRIPTOR' : _COMMEVENTPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.CommEventProto)
  })
_sym_db.RegisterMessage(CommEventProto)

PeekProto = _reflection.GeneratedProtocolMessageType('PeekProto', (_message.Message,), {
  'DESCRIPTOR' : _PEEKPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.PeekProto)
  })
_sym_db.RegisterMessage(PeekProto)

BondProto = _reflection.GeneratedProtocolMessageType('BondProto', (_message.Message,), {
  'DESCRIPTOR' : _BONDPROTO,
  '__module__' : 'CasperMessage_pb2'
  # @@protoc_insertion_point(class_scope:casper.BondProto)
  })
_sym_db.RegisterMessage(BondProto)


DESCRIPTOR._options = None
_HASBLOCKREQUESTPROTO._options = None
_HASBLOCKPROTO._options = None
_BLOCKREQUESTPROTO._options = None
_FORKCHOICETIPREQUESTPROTO._options = None
_APPROVEDBLOCKCANDIDATEPROTO._options = None
_UNAPPROVEDBLOCKPROTO._options = None
_BLOCKAPPROVALPROTO._options = None
_APPROVEDBLOCKPROTO._options = None
_APPROVEDBLOCKREQUESTPROTO._options = None
_NOAPPROVEDBLOCKAVAILABLEPROTO._options = None
_BLOCKMESSAGEPROTO._options = None
_BLOCKHASHMESSAGEPROTO._options = None
_BLOCKMETADATAINTERNAL.fields_by_name['parents']._options = None
_BLOCKMETADATAINTERNAL.fields_by_name['justifications']._options = None
_BLOCKMETADATAINTERNAL.fields_by_name['bonds']._options = None
_BLOCKMETADATAINTERNAL._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import routing_pb2 as routing__pb2


class TransportLayerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Send = channel.unary_unary(
        '/routing.TransportLayer/Send',
        request_serializer=routing__pb2.TLRequest.SerializeToString,
        response_deserializer=routing__pb2.TLResponse.FromString,
        )
    self.Stream = channel.stream_unary(
        '/routing.TransportLayer/Stream',
        request_serializer=routing__pb2.Chunk.SerializeToString,
        response_deserializer=routing__pb2.TLResponse.FromString,
        )


class TransportLayerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Send(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Stream(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TransportLayerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Send': grpc.unary_unary_rpc_method_handler(
          servicer.Send,
          request_deserializer=routing__pb2.TLRequest.FromString,
          response_serializer=routing__pb2.TLResponse.SerializeToString,
      ),
      'Stream': grpc.stream_unary_rpc_method_handler(
          servicer.Stream,
          request_deserializer=routing__pb2.Chunk.FromString,
          response_serializer=routing__pb2.TLResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'routing.TransportLayer', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ServiceError.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ServiceError.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\342?\035\n\033coop.rchain.casper.protocol'),
  serialized_pb=_b('\n\x12ServiceError.proto\x1a\x15scalapb/scalapb.proto\" \n\x0cServiceError\x12\x10\n\x08messages\x18\x01 \x03(\tB \xe2?\x1d\n\x1b\x63oop.rchain.casper.protocolb\x06proto3')
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_SERVICEERROR = _descriptor.Descriptor(
  name='ServiceError',
  full_name='ServiceError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='ServiceError.messages', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=77,
)

DESCRIPTOR.message_types_by_name['ServiceError'] = _SERVICEERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServiceError = _reflection.GeneratedProtocolMessageType('ServiceError', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEERROR,
  '__module__' : 'ServiceError_pb2'
  # @@protoc_insertion_point(class_scope:ServiceError)
  })
_sym_db.RegisterMessage(ServiceError)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import pytest
from ecdsa.keys import BadSignatureError
from rchain.crypto import PrivateKey, PublicKey, blake2b_32


@pytest.mark.parametrize('input_str,expected_output', [
        ('', '0e5751c026e543b2e8ab2eb06099daa1d1e5df47778f7787faab45cdf12fe3a8'),
        ('foo', 'b8fe9f7f6255a6fa08f668ab632a8d081ad87983c77cd274e48ce450f0b349fd'),
        (
            'sRHyrQZuEdI5WyvJD1YwCVaUpFEHCCZXF7HIIPMUIABwwr6EWNPRB1s3XkYzobM8TxHA2NHpxjzUzIxk',
            'cb44058e45aeca88339b16c53d3e2544246bc9a6aa4f831cf2099d70037aba61'
        ),
    ])
def test_blake2b_32(input_str: str, expected_output: str):
    actual_output = blake2b_32(input_str.encode()).digest().hex()
    assert expected_output == actual_output


keys_identities = [
        (
            '1000000000000000000000000000000000000000000000000000000000000000',
            '0408ea9666139527a8c1dd94ce4f071fd23c8b350c5a4bb33748c4ba111faccae0620efabbc8ee2782e24e7c0cfb95c5d735b783be9cf0f8e955af34a30e62b945',
            '1111cnoFDAa7GubxBMHpPLbbediPegnjSdZwNjxg9oqYvSvSmfqQL'
        ),
        (
            '1111111111111111111111111111111111111111111111111111111111111111',
            '044f355bdcb7cc0af728ef3cceb9615d90684bb5b2ca5f859ab0f0b704075871aa385b6b1b8ead809ca67454d9683fcf2ba03456d6fe2c4abe2b07f0fbdbb2f1c1',
            '111125UED2qbF3aman9PYvfeTk81TuP4fVL5nYsEXtFyTtaLPcHW61'
        ),
        (
            '2222222222222222222222222222222222222222222222222222222222222222',
            '04466d7fcae563e5cb09a0d1870bb580344804617879a14949cf22285f1bae3f276728176c3c6431f8eeda4538dc37c865e2784f3a9e77d044f33e407797e1278a',
            '1111yoPaoSxvmNRGDpP9GUGToHaCdUFEu3KdbNgTuyydUgg6cty7g'
        )
    ]

@pytest.mark.parametrize("key_hex,pub_key_hex,rev_address", keys_identities)
def test_privatekey_function(key_hex: str, pub_key_hex: str, rev_address: str):
    key = PrivateKey.from_hex(key_hex)
    pub_key = key.get_public_key()
    actual_pub_key_hex = pub_key.to_bytes().hex()
    assert pub_key_hex == actual_pub_key_hex

@pytest.mark.parametrize("key_hex,pub_key_hex,rev_address", keys_identities)
def test_publickey_from_hex(key_hex: str, pub_key_hex: str, rev_address: str):
    key = PrivateKey.from_hex(key_hex)
    pub_key = PublicKey.from_hex(pub_key_hex)
    expected_pub_key_bytes = key.get_public_key().to_bytes()
    actual_pub_key_bytes = pub_key.to_bytes()
    assert expected_pub_key_bytes == actual_pub_key_bytes

@pytest.mark.parametrize("key_hex,pub_key_hex,rev_address", keys_identities)
def test_key_to_hex(key_hex: str, pub_key_hex: str, rev_address: str):
    private_key = PrivateKey.from_hex(key_hex)
    assert private_key.to_hex() == key_hex
    public_key = PublicKey.from_hex(pub_key_hex)
    assert public_key.to_hex() == pub_key_hex

@pytest.mark.parametrize("key_hex,pub_key_hex,rev_address", keys_identities)
def test_sign_verify_good(key_hex: str, pub_key_hex: str, rev_address: str):
    key = PrivateKey.from_hex(key_hex)
    pub_key = PublicKey.from_hex(pub_key_hex)
    message = 'hello rchain'.encode()
    signature = key.sign(message)
    pub_key.verify(signature, message)

@pytest.mark.parametrize("key_hex,pub_key_hex,rev_address", keys_identities)
def test_sign_verify_bad(key_hex: str, pub_key_hex: str, rev_address: str):
    key = PrivateKey.from_hex(key_hex)
    pub_key = PublicKey.from_hex(pub_key_hex)
    sign_message = 'hello rchain'.encode()
    verify_message = 'hello world'.encode()
    signature = key.sign(sign_message)
    with pytest.raises(BadSignatureError):
        pub_key.verify(signature, verify_message)

@pytest.mark.parametrize("key_hex,pub_key_hex,rev_address", keys_identities)
def test_sign_block_hash_verify_good(key_hex: str, pub_key_hex: str, rev_address: str):
    key = PrivateKey.from_hex(key_hex)
    pub_key = PublicKey.from_hex(pub_key_hex)
    message = 'hello rchain'.encode()
    digest = blake2b_32(message).digest()
    signature = key.sign_block_hash(digest)
    pub_key.verify_block_hash(signature, digest)

@pytest.mark.parametrize("key_hex,pub_key_hex,rev_address", keys_identities)
def test_sign_block_hash_verify_bad(key_hex: str, pub_key_hex: str, rev_address: str):
    key = PrivateKey.from_hex(key_hex)
    pub_key = PublicKey.from_hex(pub_key_hex)
    sign_message = 'hello rchain'.encode()
    verify_message = 'hello world'.encode()
    block_hash = blake2b_32(sign_message).digest()
    signature = key.sign_block_hash(block_hash)
    verify_digest = blake2b_32(verify_message).digest()
    with pytest.raises(BadSignatureError):
        pub_key.verify_block_hash(signature, verify_digest)

@pytest.mark.parametrize("key_hex,pub_key_hex,rev_address", keys_identities)
def test_address(key_hex: str, pub_key_hex: str, rev_address: str):
    pub_key = PublicKey.from_hex(pub_key_hex)
    actual_address = pub_key.get_rev_address()
    assert rev_address == actual_address
